<?php

/**
 * Class for reading from and writing to asterisk config file
 */
class ConfigManager
{

    /** @var path to config file */
    private $config;

    public function __construct($config)
    {
        $this->config = $config;
    }

    /**
     * Read all parameters from config
     * 
     * @return array
     */
    public function getParams()
    {
        $lines = file($this->config);
        $lines = array_map('trim', $lines);

        foreach ($lines as $key => $line) {
            if (!$line || strpos($line, ';') === 0) {
                unset($lines[$key]);
            }
        }

        $params = array();

        foreach ($lines as $line) {
            if (preg_match('/([a-z_]+) =>? ([^ ;]+)(?= |$)/', $line, $matches)) {
                $params[$matches[1]] = $matches[2];
            }
        }

        return $params;
    }

    /**
     * Read parameter from config
     * 
     * @param  string $name
     * @return array
     */
    public function getParam($name)
    {
        $params = $this->getParams();

        return isset($params[$name]) ? $params[$name] : null;
    }

    /**
     * Write parameter to config
     *
     * If parameter already set, updates the line 
     * Preserves trailing commends, trims lieading comments
     * If parameter is not set, ignores it
     * 
     * @param string $name
     * @param string $value
     */
    public function setParam($name, $value)
    {
        $this->setParams(array($name => $value));
    }

    public function setParams(array $params)
    {
        $lines = file($this->config);

        foreach ($lines as $key => $line) {
            if (preg_match('/^(?:;#?)?([a-z_]+)( =>? )([^ ;]*)((?: ; .+)?\n?) *$/', $line, $matches)) {
                if (isset($params[$matches[1]])) {
                    $lines[$key] = $matches[1] . $matches[2] . $params[$matches[1]] . $matches[4] . "\n";
                    unset($params[$matches[1]]);

                    if (empty($params)) {
                        break;
                    }
                }
            }
        }

        file_put_contents($this->config, $lines);
    }

}
